Documentation
¶
Index ¶
Constants ¶
const CfServicesMetadataKind types.Kind = "CfServices"
CfServicesMetadataKind defines kind of cf services file
const ClusterMetadataKind types.Kind = "ClusterMetadata"
ClusterMetadataKind defines the kind of cluster metadata file
const ClusterQaLabelKey = types.GroupName + "/clusterqalabel"
ClusterQaLabelKey is the keyname for the clusterqalabel Key
const DefaultClusterSpecificQaLabel = "default"
DefaultClusterSpecificQaLabel defines the default storage QA label to be used in the absence of any user-defined name
const ImageInfoKind types.Kind = "ImageInfo"
ImageInfoKind defines kind for imagesmetadata file
const ImageMetadataKind types.Kind = "ImageMetadata"
ImageMetadataKind defines kind for imagemetadata file
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CfServices ¶ added in v0.3.0
type CfServices struct {
types.TypeMeta `yaml:",inline"`
types.ObjectMeta `yaml:"metadata,omitempty"`
Spec CfServicesSpec `yaml:"spec,omitempty"`
}
CfServices defines definition of cf runtime instance apps file
func NewCfServices ¶ added in v0.3.0
func NewCfServices() CfServices
NewCfServices creates a new instance of CfServices
type CfServicesSpec ¶ added in v0.3.0
CfServicesSpec stores the data
type ClusterMetadata ¶
type ClusterMetadata struct {
types.TypeMeta `yaml:",inline"`
types.ObjectMeta `yaml:"metadata,omitempty"`
Spec ClusterMetadataSpec `yaml:"spec,omitempty"`
}
ClusterMetadata for collect output
func NewClusterMetadata ¶
func NewClusterMetadata(contextName string) ClusterMetadata
NewClusterMetadata creates a new cluster metadata instance
func (*ClusterMetadata) Merge ¶
func (c *ClusterMetadata) Merge(nc interface{}) bool
Merge merges two ClusterMetadatas
type ClusterMetadataSpec ¶
type ClusterMetadataSpec struct {
StorageClasses []string `yaml:"storageClasses"`
APIKindVersionMap map[string][]string `yaml:"apiKindVersionMap"` //[kubernetes kind]["gv1", "gv2",...,"gvn"] prioritized group-version
Host string `yaml:"host,omitempty"` // Optional field, either collected with move2kube collect or by asking the user.
}
ClusterMetadataSpec stores the data
func (*ClusterMetadataSpec) GetSupportedVersions ¶
func (c *ClusterMetadataSpec) GetSupportedVersions(kind string) []string
GetSupportedVersions returns all the group version supported for the kind in this cluster
func (*ClusterMetadataSpec) Merge ¶
func (c *ClusterMetadataSpec) Merge(newc ClusterMetadataSpec) bool
Merge helps merge clustermetadata
type ImageInfo ¶
type ImageInfo struct {
types.TypeMeta `yaml:",inline"`
types.ObjectMeta `yaml:"metadata,omitempty"`
Spec ImageInfoSpec `yaml:"spec,omitempty"`
}
ImageInfo stores data about different images
type ImageInfoSpec ¶
type ImageInfoSpec struct {
Tags []string `yaml:"tags"`
PortsToExpose []int32 `yaml:"ports"`
AccessedDirs []string `yaml:"accessedDirs"`
UserID int `yaml:"userID"`
Created string `json:"created,omitempty" yaml:"created,omitempty"`
Params map[string]string `json:"params,omitempty" yaml:"params,omitempty"`
}
ImageInfoSpec defines the data stored about ImageInfo
type ImagesInfo ¶ added in v0.3.0
type ImagesInfo struct {
types.TypeMeta `yaml:",inline"`
types.ObjectMeta `yaml:"metadata,omitempty"`
Spec []ImageInfoSpec `yaml:"spec,omitempty"`
}
ImagesInfo stores data about different images
func NewImagesInfo ¶ added in v0.3.0
func NewImagesInfo() ImagesInfo
NewImagesInfo creates a new imagesinfo instance