Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Container ¶
type Container struct {
// ID is the id of the running container.
ID string `yaml:"-"`
// Image is the image name and tag to use when starting the container.
Image string `yaml:"image"`
// KeepAliveCommand is the command to run when starting the container.
// It should keep the container alive so that the detect and transform commands can be executed later.
// By default we will use the entrypoint of the container.
KeepAliveCommand []string `yaml:"keepAliveCommand,omitempty"`
// WorkingDir is the directory where the command will be run.
WorkingDir string `yaml:"workingDir,omitempty"`
// ImageBuild contains the instructions to build the image used by this container.
ImageBuild ImageBuild `yaml:"build"`
}
Container stores container based execution information
type EnvPlatformConfig ¶ added in v0.3.5
type EnvPlatformConfig struct {
Container Container `yaml:"container,omitempty"`
Platforms []string `yaml:"platforms"`
}
EnvPlatformConfig stores the platform specific details
type ImageBuild ¶ added in v0.3.5
type ImageBuild struct {
ForceRebuild bool `yaml:"forceRebuild"` // Force rebuild the image even if it exists
Dockerfile string `yaml:"dockerfile"` // Default : Look for Dockerfile in the same folder
Context string `yaml:"context"` // Default : Same folder as the yaml
}
ImageBuild stores container build information
Click to show internal directories.
Click to hide internal directories.